==> kubernetes-model-admissionregistration-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1/ServiceReferenceFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ServiceReferenceFluent<A extends ServiceReferenceFluent<A>> extends Fluent<A> {


    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    public String getNamespace();
    public A withNamespace(String namespace);
    public Boolean hasNamespace();
    public A withNewNamespace(StringBuilder arg1);
    public A withNewNamespace(int[] arg1,int arg2,int arg3);
    public A withNewNamespace(char[] arg1);
    public A withNewNamespace(StringBuffer arg1);
    public A withNewNamespace(byte[] arg1,int arg2);
    public A withNewNamespace(byte[] arg1);
    public A withNewNamespace(char[] arg1,int arg2,int arg3);
    public A withNewNamespace(byte[] arg1,int arg2,int arg3);
    public A withNewNamespace(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewNamespace(String arg1);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(int[] arg1,int arg2,int arg3);
    public A withNewPath(char[] arg1);
    public A withNewPath(StringBuffer arg1);
    public A withNewPath(byte[] arg1,int arg2);
    public A withNewPath(byte[] arg1);
    public A withNewPath(char[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPath(String arg1);
    public Integer getPort();
    public A withPort(Integer port);
    public Boolean hasPort();
    public A withNewPort(int arg1);
}

==> kubernetes-model-admissionregistration-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1/ServiceReferenceFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ServiceReferenceFluent<A extends ServiceReferenceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    public String getNamespace();
    public A withNamespace(String namespace);
    public Boolean hasNamespace();
    public A withNewNamespace(StringBuilder arg1);
    public A withNewNamespace(int[] arg1,int arg2,int arg3);
    public A withNewNamespace(char[] arg1);
    public A withNewNamespace(StringBuffer arg1);
    public A withNewNamespace(byte[] arg1,int arg2);
    public A withNewNamespace(byte[] arg1);
    public A withNewNamespace(char[] arg1,int arg2,int arg3);
    public A withNewNamespace(byte[] arg1,int arg2,int arg3);
    public A withNewNamespace(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewNamespace(String arg1);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(int[] arg1,int arg2,int arg3);
    public A withNewPath(char[] arg1);
    public A withNewPath(StringBuffer arg1);
    public A withNewPath(byte[] arg1,int arg2);
    public A withNewPath(byte[] arg1);
    public A withNewPath(char[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPath(String arg1);
    public Integer getPort();
    public A withPort(Integer port);
    public Boolean hasPort();
    public A withNewPort(int arg0);
}
